# File: IndianaStreams.s
# Purpose: Estimation for Indiana Upper Wabash River Basin Biological Status
# Programmers: Tony Olsen and Tom Kincaid
# Date: October 29, 2006


# Load the psurvey.analysis library

library(psurvey.analysis)

# Read the data file

INstreamdata <- read.table("INstreamdata.tab", header=T, row.names=NULL, sep="\t")
cat("The initial six lines in the data file follow:\n\n")
print(INstreamdata[1:6,])

# Print a table displaying the count for each code for variable StatusB -
#    biological site evaluation status
# The meaning for each code follows:
#    TS - target and sampled site
#    NT - site was non-target (dry, non-wadeable, ...)
#    LD - landowner denied access to site
#    PB - physical barrier - unable to reach site
#    OT - target site for which a sample was not collected
#    UK - Unknown whether site is target or non-target (shouldn't happen)
#    SCNB - target site Sampled for Chemistry but Not Biology (sampled fewer
#           biology sites)

cat("\nA table displaying the number of values for each level of the site status variable follows:\n")
print(table(INstreamdata$StatusB))

# Print a table displaying the count for each code for variable StatusTNT, where
#    T equals Target sites and NT equals NonTarget sites
# The meaning for each code follows:
#    T - categories "TS", "LD", "OT", "SCNB", and "PB" from the StatusB variable
#    NT - categories "NT", and "UK" from the StatusB variable

cat("\nA table displaying the number of values for each level of the Target/NonTarget site status variable follows:\n")
print(table(INstreamdata$StatusTNT))


# Conduct an analysis of site evaluation categories

# Create the sites data frame, which identifies sites to use in the analysis
# Note that all sites will be used to estimate stream length in each category

sites <- data.frame(siteID=INstreamdata$SiteID,
                    Use=I(rep(TRUE, nrow(INstreamdata))))

# Create the subpop data frame, which defines populations and subpopulations for
#    which estimates are desired
# Note that the only population is the entire Upper Wabash Basin

subpop <- data.frame(siteID=INstreamdata$SiteID,
                     UpperWabash=INstreamdata$Basin)

# Create the design data frame, which identifies the stratum code, weight,
#    x-coordinate, and y-coordinate for each site ID

design <- data.frame(siteID=INstreamdata$SiteID,
                     stratum=INstreamdata$Stratum,
                     wgt=INstreamdata$final.wt,
                     xcoord=INstreamdata$xmarinus,
                     ycoord=INstreamdata$ymarinus)

# Create the data.cat data frame, which specifies the variables to use in the
#    analysis

data.cat <- data.frame(siteID=INstreamdata$SiteID,
                       BiologicalStatus=INstreamdata$StatusB,
                       StatusTNT=INstreamdata$StatusTNT)

# Produce estimates for the site evaluation variables
# Note that argument popsize was set equal to the known length of the frame for 
#    the Upper Wabash Basin

SiteStatusSum <- cat.analysis(sites, subpop, design, data.cat,
                              popsize=list(UpperWabash=7358.150))
				         
# Write results as a comma-separated value (csv) file to read into a spreadsheet

write.table(SiteStatusSum, file="SiteStatusSum.csv", sep=",", dimnames.write="colnames")


# Conduct an analysis of IBI status and QHEI status

# Create the sites data frame
# Note that only Target sites (category "TS" for the StatusB variable) are used

sites <- data.frame(siteID=INstreamdata$SiteID,
                    Use=I(INstreamdata$StatusB == "TS"))

# Note that the existing subpop and design data frames can be used

# Create the data.cat data frame

data.cat <- data.frame(siteID=INstreamdata$SiteID,
                       IBIStatus=INstreamdata$IBI.Status,
                       QHEIStatus=INstreamdata$QHEI.Status)
						
# Produce estimates for the IBI status and QHEI status variables
# Note that the size of the target stream length is not known, so argument
#    popsize is not specified

ConditionSum <- cat.analysis(sites, subpop, design, data.cat)

# Write results as a csv file to read into a spreadsheet

write.table(ConditionSum, file="ConditionSum.csv", sep=",", dimnames.write="colnames")


# Conduct an analysis of IBI score and QHEI score

# Note that the existing sites, subpop, and design data frames can be used

# Create the data.cont data frame

data.cont <- data.frame(siteID=INstreamdata$SiteID,
                        IBIScore=INstreamdata$IBI.Score,
                        QHEIScore=INstreamdata$QHEI.Score)
				
# Produce estimates for the IBI score and QHEI score variables

ScoresSum <- cont.analysis(sites, subpop, design, data.cont)

# Write results as csv files to read in spreadsheets

write.table(ScoresSum$CDF, file="ScoresSumCDF.csv", sep=",", dimnames.write="colnames")
write.table(ScoresSum$Pct, file="ScoresSumPct.csv", sep=",", dimnames.write="colnames")
